// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('starter', ['ionic', 'gracenote.controllers', 'gracenote.services'])

.run(function($ionicPlatform) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
      cordova.plugins.Keyboard.disableScroll(false);
    }
    if (window.StatusBar) {
      // org.apache.cordova.statusbar required
      StatusBar.styleDefault();
    }
    ionic.Platform.isFullScreen = true;
  });
})

.config(function($stateProvider, $urlRouterProvider) {

  // Ionic uses AngularUI Router which uses the concept of states
  // Learn more here: https://github.com/angular-ui/ui-router
  // Set up the various states which the app can be in.
  // Each state's controller can be found in controllers.js
  $stateProvider

    .state('login', {
      url: '/login',
      templateUrl: 'templates/login.html',
      controller: 'LoginCtrl'
    })

    .state('agreement', {
      url: '/agreement',
      templateUrl: 'templates/agreement.html',
      controller: 'AgreementCtrl'
    })

  // setup an abstract state for the tabs directive
    .state('tab', {
    url: "/tab",
    abstract: true,
    templateUrl: "templates/tabs.html"
  })
  
  // feed states
  
  .state('tab.feed', {
    url: '/feed',
    views: {
      'tab-notefeed': {
        templateUrl: 'templates/notefeed.html',
        controller: 'NoteFeedCtrl'
      }
    }
  })
    .state('tab.feednoteview', {
      url: '/feednoteview/:noteid',
      views: {
        'tab-notefeed': {
          templateUrl: 'templates/noteview.html',
          controller: 'NoteViewCtrl'
        }
      }
    })

    .state('tab.feeduserview', {
      url: '/feeduserview/:notefid',
      views: {
        'tab-notefeed': {
          templateUrl: 'templates/userview.html',
          controller: 'UserViewCtrl'
        }
      }
    })

    .state('tab.feedaddcomment', {
      url: '/feedaddcomment/:noteid',
      views: {
        'tab-notefeed': {
          templateUrl: 'templates/addcomment.html',
          controller: 'AddCommentCtrl'
        }
      }
    })

    .state('tab.feednewnote', {
      url: '/feednewnote',
      views: {
        'tab-notefeed': {
          templateUrl: 'templates/newnote.html',
          controller: 'NewNoteCtrl'
        }
      }
    })

    .state('tab.feedamenview', {
      url: '/feedamenview/:noteid',
      views: {
        'tab-notefeed': {
          templateUrl: 'templates/amenview.html',
          controller: 'AmenCtrl'
        }
      }
    })
    .state('tab.feedfavview', {
      url: '/feedfavview/:noteid',
      views: {
        'tab-notefeed': {
          templateUrl: 'templates/favview.html',
          controller: 'FavCtrl'
        }
      }
    })

    
    
    // favorite states
    
  .state('tab.favorites', {
      url: '/favorites',
      views: {
        'tab-favorites': {
          templateUrl: 'templates/favorites.html',
          controller: 'NoteFavoriteCtrl'
        }
      }
    })

    .state('tab.favnoteview', {
      url: '/favnoteview/:noteid',
      views: {
        'tab-favorites': {
          templateUrl: 'templates/noteview.html',
          controller: 'NoteViewCtrl'
        }
      }
    })

    .state('tab.favuserview', {
      url: '/favuserview/:notefid',
      views: {
        'tab-favorites': {
          templateUrl: 'templates/userview.html',
          controller: 'UserViewCtrl'
        }
      }
    })

    .state('tab.favaddcomment', {
      url: '/favaddcomment/:noteid',
      views: {
        'tab-favorites': {
          templateUrl: 'templates/addcomment.html',
          controller: 'AddCommentCtrl'
        }
      }
    })

    .state('tab.favnewnote', {
      url: '/favnewnote',
      views: {
        'tab-favorites': {
          templateUrl: 'templates/newnote.html',
          controller: 'NewNoteCtrl'
        }
      }
    })
    .state('tab.favamenview', {
      url: '/favamenview/:noteid',
      views: {
        'tab-favorites': {
          templateUrl: 'templates/amenview.html',
          controller: 'AmenCtrl'
        }
      }
    })
    .state('tab.favfavview', {
      url: '/favfavview/:noteid',
      views: {
        'tab-favorites': {
          templateUrl: 'templates/favview.html',
          controller: 'FavCtrl'
        }
      }
    })

    
    
    
    // wall states
    
    .state('tab.notewall', {
      url: '/notewall',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/notewall.html',
          controller: 'NoteWallCtrl'
        }
      }
    })

    
    .state('tab.wallfollowing', {
      url: '/wallfollowing/:fid',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/following.html',
          controller: 'FollowingCtrl'
        }
      }
    })

    .state('tab.wallfollower', {
      url: '/wallfollower/:fid',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/follower.html',
          controller: 'FollowerCtrl'
        }
      }
    })

    .state('tab.wallprofile', {
      url: '/wallprofile/:fid',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/profile.html',
          controller: 'ProfileCtrl'
        }
      }
    })

    .state('tab.wallupdatenote', {
      url: '/wallupdatenote/:noteid',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/updatenote.html',
          controller: 'UpdateNoteCtrl'
        }
      }
    })

    .state('tab.wallnoteview', {
      url: '/wallnoteview/:noteid',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/noteview.html',
          controller: 'NoteViewCtrl'
        }
      }
    })

    .state('tab.walluserview', {
      url: '/walluserview/:notefid',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/userview.html',
          controller: 'UserViewCtrl'
        }
      }
    })

    .state('tab.walladdcomment', {
      url: '/walladdcomment/:noteid',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/addcomment.html',
          controller: 'AddCommentCtrl'
        }
      }
    })

    .state('tab.wallnewnote', {
      url: '/wallnewnote',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/newnote.html',
          controller: 'NewNoteCtrl'
        }
      }
    })
    .state('tab.wallamenview', {
      url: '/wallamenview/:noteid',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/amenview.html',
          controller: 'AmenCtrl'
        }
      }
    })
    .state('tab.wallfavview', {
      url: '/wallfavview/:noteid',
      views: {
        'tab-notewall': {
          templateUrl: 'templates/favview.html',
          controller: 'FavCtrl'
        }
      }
    })

  
    
    
    // notification states
    
    
    
  .state('tab.notifications', {
      url: '/events',
      views: {
        'tab-events': {
          templateUrl: 'templates/noteevents.html',
          controller: 'EventCtrl'
        }
      }
    })

    .state('tab.eventnewnote', {
      url: '/eventnewnote',
      views: {
        'tab-events': {
          templateUrl: 'templates/newnote.html',
          controller: 'NewNoteCtrl'
        }
      }
    })

    .state('tab.eventnoteview', {
      url: '/eventnoteview/:noteid',
      views: {
        'tab-events': {
          templateUrl: 'templates/noteview.html',
          controller: 'NoteViewCtrl'
        }
      }
    })
    .state('tab.eventuserview', {
      url: '/eventuserview/:notefid',
      views: {
        'tab-events': {
          templateUrl: 'templates/userview.html',
          controller: 'UserViewCtrl'
        }
      }
    })

    .state('tab.eventaddcomment', {
      url: '/eventaddcomment/:noteid',
      views: {
        'tab-events': {
          templateUrl: 'templates/addcomment.html',
          controller: 'AddCommentCtrl'
        }
      }
    })
    .state('tab.eventamenview', {
      url: '/eventamenview/:noteid',
      views: {
        'tab-events': {
          templateUrl: 'templates/amenview.html',
          controller: 'AmenCtrl'
        }
      }
    })
    .state('tab.eventfavview', {
      url: '/eventfavview/:noteid',
      views: {
        'tab-events': {
          templateUrl: 'templates/favview.html',
          controller: 'FavCtrl'
        }
      }
    })
    
    
    
    
    
    
  // search states

  
    .state('tab.search', {
      url: '/search',
      views: {
        'tab-search': {
          templateUrl: 'templates/search.html',
          controller: 'SearchCtrl'
        }
      }
    })
    
    .state('tab.searchnoteview', {
      url: '/searchnoteview/:noteid',
      views: {
        'tab-search': {
          templateUrl: 'templates/noteview.html',
          controller: 'NoteViewCtrl'
        }
      }
    })

    .state('tab.searchuserview', {
      url: '/searchuserview/:notefid',
      views: {
        'tab-search': {
          templateUrl: 'templates/userview.html',
          controller: 'UserViewCtrl'
        }
      }
    })

    .state('tab.searchaddcomment', {
      url: '/searchaddcomment/:noteid',
      views: {
        'tab-search': {
          templateUrl: 'templates/addcomment.html',
          controller: 'AddCommentCtrl'
        }
      }
    })

    .state('tab.searchnewnote', {
      url: '/searchnewnote',
      views: {
        'tab-search': {
          templateUrl: 'templates/newnote.html',
          controller: 'NewNoteCtrl'
        }
      }
    })

    .state('tab.searchamenview', {
      url: '/searchamenview/:noteid',
      views: {
        'tab-search': {
          templateUrl: 'templates/amenview.html',
          controller: 'AmenCtrl'
        }
      }
    })
    .state('tab.searchfavview', {
      url: '/searchfavview/:noteid',
      views: {
        'tab-search': {
          templateUrl: 'templates/favview.html',
          controller: 'FavCtrl'
        }
      }
    })

    
  // if none of the above states are matched, use this as the fallback
  $urlRouterProvider.otherwise('/login');

});
